==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1ProjectedVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class V1ProjectedVolumeSourceFluentImpl<A extends V1ProjectedVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1ProjectedVolumeSourceFluent<A>{

    private Integer defaultMode;
    private List<V1VolumeProjectionBuilder> sources;

    public V1ProjectedVolumeSourceFluentImpl(){
    }
    public V1ProjectedVolumeSourceFluentImpl(V1ProjectedVolumeSource instance){
            this.withDefaultMode(instance.getDefaultMode());

            this.withSources(instance.getSources());

    }

    public Integer getDefaultMode(){
            return this.defaultMode;
    }

    public A withDefaultMode(Integer defaultMode){
            this.defaultMode=defaultMode; return (A) this;
    }

    public Boolean hasDefaultMode(){
            return this.defaultMode != null;
    }

    public A withNewDefaultMode(int arg1){
            return (A)withDefaultMode(new Integer(arg1));
    }

    public A withNewDefaultMode(String arg1){
            return (A)withDefaultMode(new Integer(arg1));
    }

    public A addToSources(int index,V1VolumeProjection item){
            if (this.sources == null) {this.sources = new ArrayList<V1VolumeProjectionBuilder>();}
            V1VolumeProjectionBuilder builder = new V1VolumeProjectionBuilder(item);_visitables.add(index >= 0 ? index : _visitables.size(), builder);this.sources.add(index >= 0 ? index : sources.size(), builder); return (A)this;
    }

    public A setToSources(int index,V1VolumeProjection item){
            if (this.sources == null) {this.sources = new ArrayList<V1VolumeProjectionBuilder>();}
            V1VolumeProjectionBuilder builder = new V1VolumeProjectionBuilder(item);
            if (index < 0 || index >= _visitables.size()) { _visitables.add(builder); } else { _visitables.set(index, builder);}
            if (index < 0 || index >= sources.size()) { sources.add(builder); } else { sources.set(index, builder);}
             return (A)this;
    }

    public A addToSources(V1VolumeProjection... items){
            if (this.sources == null) {this.sources = new ArrayList<V1VolumeProjectionBuilder>();}
            for (V1VolumeProjection item : items) {V1VolumeProjectionBuilder builder = new V1VolumeProjectionBuilder(item);_visitables.add(builder);this.sources.add(builder);} return (A)this;
    }

    public A addAllToSources(Collection<V1VolumeProjection> items){
            if (this.sources == null) {this.sources = new ArrayList<V1VolumeProjectionBuilder>();}
            for (V1VolumeProjection item : items) {V1VolumeProjectionBuilder builder = new V1VolumeProjectionBuilder(item);_visitables.add(builder);this.sources.add(builder);} return (A)this;
    }

    public A removeFromSources(V1VolumeProjection... items){
            for (V1VolumeProjection item : items) {V1VolumeProjectionBuilder builder = new V1VolumeProjectionBuilder(item);_visitables.remove(builder);if (this.sources != null) {this.sources.remove(builder);}} return (A)this;
    }

    public A removeAllFromSources(Collection<V1VolumeProjection> items){
            for (V1VolumeProjection item : items) {V1VolumeProjectionBuilder builder = new V1VolumeProjectionBuilder(item);_visitables.remove(builder);if (this.sources != null) {this.sources.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildSources instead.
 * @return The buildable object.
 */
@Deprecated public List<V1VolumeProjection> getSources(){
            return build(sources);
    }

    public List<V1VolumeProjection> buildSources(){
            return build(sources);
    }

    public V1VolumeProjection buildSource(int index){
            return this.sources.get(index).build();
    }

    public V1VolumeProjection buildFirstSource(){
            return this.sources.get(0).build();
    }

    public V1VolumeProjection buildLastSource(){
            return this.sources.get(sources.size() - 1).build();
    }

    public V1VolumeProjection buildMatchingSource(io.kubernetes.client.fluent.Predicate<V1VolumeProjectionBuilder> predicate){
            for (V1VolumeProjectionBuilder item: sources) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public A withSources(List<V1VolumeProjection> sources){
            if (this.sources != null) { _visitables.removeAll(this.sources);}
            if (sources != null) {this.sources = new ArrayList<V1VolumeProjectionBuilder>(); for (V1VolumeProjection item : sources){this.addToSources(item);}} else { this.sources = null;} return (A) this;
    }

    public A withSources(V1VolumeProjection... sources){
            if (this.sources != null) {this.sources.clear();}
            if (sources != null) {for (V1VolumeProjection item :sources){ this.addToSources(item);}} return (A) this;
    }

    public Boolean hasSources(){
            return sources != null && !sources.isEmpty();
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> addNewSource(){
            return new SourcesNestedImpl();
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> addNewSourceLike(V1VolumeProjection item){
            return new SourcesNestedImpl(-1, item);
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> setNewSourceLike(int index,V1VolumeProjection item){
            return new SourcesNestedImpl(index, item);
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editSource(int index){
            if (sources.size() <= index) throw new RuntimeException("Can't edit sources. Index exceeds size.");
            return setNewSourceLike(index, buildSource(index));
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editFirstSource(){
            if (sources.size() == 0) throw new RuntimeException("Can't edit first sources. The list is empty.");
            return setNewSourceLike(0, buildSource(0));
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editLastSource(){
            int index = sources.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last sources. The list is empty.");
            return setNewSourceLike(index, buildSource(index));
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editMatchingSource(io.kubernetes.client.fluent.Predicate<V1VolumeProjectionBuilder> predicate){
            int index = -1;
            for (int i=0;i<sources.size();i++) { 
            if (predicate.apply(sources.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching sources. No match found.");
            return setNewSourceLike(index, buildSource(index));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1ProjectedVolumeSourceFluentImpl that = (V1ProjectedVolumeSourceFluentImpl) o;
            if (defaultMode != null ? !defaultMode.equals(that.defaultMode) :that.defaultMode != null) return false;
            if (sources != null ? !sources.equals(that.sources) :that.sources != null) return false;
            return true;
    }


    public class SourcesNestedImpl<N> extends V1VolumeProjectionFluentImpl<V1ProjectedVolumeSourceFluent.SourcesNested<N>> implements V1ProjectedVolumeSourceFluent.SourcesNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1VolumeProjectionBuilder builder;
        private final int index;
    
            SourcesNestedImpl(int index,V1VolumeProjection item){
                    this.index = index;
                    this.builder = new V1VolumeProjectionBuilder(this, item);
            }
            SourcesNestedImpl(){
                    this.index = -1;
                    this.builder = new V1VolumeProjectionBuilder(this);
            }
    
    public N and(){
            return (N) V1ProjectedVolumeSourceFluentImpl.this.setToSources(index, builder.build());
    }
    public N endSource(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ProjectedVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class V1ProjectedVolumeSourceFluentImpl<A extends V1ProjectedVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1ProjectedVolumeSourceFluent<A>{

    private Integer defaultMode;
    private List<V1VolumeProjectionBuilder> sources;

    public V1ProjectedVolumeSourceFluentImpl(){
    }
    public V1ProjectedVolumeSourceFluentImpl(V1ProjectedVolumeSource instance){
            this.withDefaultMode(instance.getDefaultMode());

            this.withSources(instance.getSources());

    }

    public Integer getDefaultMode(){
            return this.defaultMode;
    }

    public A withDefaultMode(Integer defaultMode){
            this.defaultMode=defaultMode; return (A) this;
    }

    public Boolean hasDefaultMode(){
            return this.defaultMode != null;
    }

    public A addToSources(int index,V1VolumeProjection item){
            if (this.sources == null) {this.sources = new ArrayList<V1VolumeProjectionBuilder>();}
            V1VolumeProjectionBuilder builder = new V1VolumeProjectionBuilder(item);_visitables.get("sources").add(index >= 0 ? index : _visitables.get("sources").size(), builder);this.sources.add(index >= 0 ? index : sources.size(), builder); return (A)this;
    }

    public A setToSources(int index,V1VolumeProjection item){
            if (this.sources == null) {this.sources = new ArrayList<V1VolumeProjectionBuilder>();}
            V1VolumeProjectionBuilder builder = new V1VolumeProjectionBuilder(item);
            if (index < 0 || index >= _visitables.get("sources").size()) { _visitables.get("sources").add(builder); } else { _visitables.get("sources").set(index, builder);}
            if (index < 0 || index >= sources.size()) { sources.add(builder); } else { sources.set(index, builder);}
             return (A)this;
    }

    public A addToSources(V1VolumeProjection... items){
            if (this.sources == null) {this.sources = new ArrayList<V1VolumeProjectionBuilder>();}
            for (V1VolumeProjection item : items) {V1VolumeProjectionBuilder builder = new V1VolumeProjectionBuilder(item);_visitables.get("sources").add(builder);this.sources.add(builder);} return (A)this;
    }

    public A addAllToSources(Collection<V1VolumeProjection> items){
            if (this.sources == null) {this.sources = new ArrayList<V1VolumeProjectionBuilder>();}
            for (V1VolumeProjection item : items) {V1VolumeProjectionBuilder builder = new V1VolumeProjectionBuilder(item);_visitables.get("sources").add(builder);this.sources.add(builder);} return (A)this;
    }

    public A removeFromSources(V1VolumeProjection... items){
            for (V1VolumeProjection item : items) {V1VolumeProjectionBuilder builder = new V1VolumeProjectionBuilder(item);_visitables.get("sources").remove(builder);if (this.sources != null) {this.sources.remove(builder);}} return (A)this;
    }

    public A removeAllFromSources(Collection<V1VolumeProjection> items){
            for (V1VolumeProjection item : items) {V1VolumeProjectionBuilder builder = new V1VolumeProjectionBuilder(item);_visitables.get("sources").remove(builder);if (this.sources != null) {this.sources.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildSources instead.
 * @return The buildable object.
 */
@Deprecated public List<V1VolumeProjection> getSources(){
            return build(sources);
    }

    public List<V1VolumeProjection> buildSources(){
            return build(sources);
    }

    public V1VolumeProjection buildSource(int index){
            return this.sources.get(index).build();
    }

    public V1VolumeProjection buildFirstSource(){
            return this.sources.get(0).build();
    }

    public V1VolumeProjection buildLastSource(){
            return this.sources.get(sources.size() - 1).build();
    }

    public V1VolumeProjection buildMatchingSource(io.kubernetes.client.fluent.Predicate<V1VolumeProjectionBuilder> predicate){
            for (V1VolumeProjectionBuilder item: sources) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public Boolean hasMatchingSource(io.kubernetes.client.fluent.Predicate<V1VolumeProjectionBuilder> predicate){
            for (V1VolumeProjectionBuilder item: sources) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withSources(List<V1VolumeProjection> sources){
            if (this.sources != null) { _visitables.get("sources").removeAll(this.sources);}
            if (sources != null) {this.sources = new ArrayList<V1VolumeProjectionBuilder>(); for (V1VolumeProjection item : sources){this.addToSources(item);}} else { this.sources = null;} return (A) this;
    }

    public A withSources(V1VolumeProjection... sources){
            if (this.sources != null) {this.sources.clear();}
            if (sources != null) {for (V1VolumeProjection item :sources){ this.addToSources(item);}} return (A) this;
    }

    public Boolean hasSources(){
            return sources != null && !sources.isEmpty();
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> addNewSource(){
            return new SourcesNestedImpl();
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> addNewSourceLike(V1VolumeProjection item){
            return new SourcesNestedImpl(-1, item);
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> setNewSourceLike(int index,V1VolumeProjection item){
            return new SourcesNestedImpl(index, item);
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editSource(int index){
            if (sources.size() <= index) throw new RuntimeException("Can't edit sources. Index exceeds size.");
            return setNewSourceLike(index, buildSource(index));
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editFirstSource(){
            if (sources.size() == 0) throw new RuntimeException("Can't edit first sources. The list is empty.");
            return setNewSourceLike(0, buildSource(0));
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editLastSource(){
            int index = sources.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last sources. The list is empty.");
            return setNewSourceLike(index, buildSource(index));
    }

    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editMatchingSource(io.kubernetes.client.fluent.Predicate<V1VolumeProjectionBuilder> predicate){
            int index = -1;
            for (int i=0;i<sources.size();i++) { 
            if (predicate.apply(sources.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching sources. No match found.");
            return setNewSourceLike(index, buildSource(index));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1ProjectedVolumeSourceFluentImpl that = (V1ProjectedVolumeSourceFluentImpl) o;
            if (defaultMode != null ? !defaultMode.equals(that.defaultMode) :that.defaultMode != null) return false;
            if (sources != null ? !sources.equals(that.sources) :that.sources != null) return false;
            return true;
    }


    public class SourcesNestedImpl<N> extends V1VolumeProjectionFluentImpl<V1ProjectedVolumeSourceFluent.SourcesNested<N>> implements V1ProjectedVolumeSourceFluent.SourcesNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1VolumeProjectionBuilder builder;
        private final int index;
    
            SourcesNestedImpl(int index,V1VolumeProjection item){
                    this.index = index;
                    this.builder = new V1VolumeProjectionBuilder(this, item);
            }
            SourcesNestedImpl(){
                    this.index = -1;
                    this.builder = new V1VolumeProjectionBuilder(this);
            }
    
    public N and(){
            return (N) V1ProjectedVolumeSourceFluentImpl.this.setToSources(index, builder.build());
    }
    public N endSource(){
            return and();
    }

}


}
